pub struct Cli {
pub all: CommitsToConsider,
pub base: Option<String>,
pub choose: PromptUserToChooseCommits,
pub dry_run: bool,
pub github_token: Option<String>,
pub overlay: OverlayCommitsIntoOnePullRequest,
pub ready: bool,
pub separate: CommitGrouping,
}Fields
all: CommitsToConsiderDo not ignore commits without an issue trailer.
Commits without an issue trailer are considered to be their own group, so will be the only commit in their PR.
There is no change to commits with an issue trailer.
This flag can be combined with the –choose flag.
base: Option<String>The starting point (exclusive) of commits to act on.
Defaults to the repository’s default branch.
choose: PromptUserToChooseCommitsPrompt the user to select which issues to create PRs for.
Select a whitelist of issues (or commits, if the –all flag is active) in a terminal UI.
dry_run: boolShow the work that would be performed without taking any action.
github_token: Option<String>GitHub API token with repo permissions.
If not provided, git-disjoint will attempt to resolve a token
from the GitHub CLI (gh auth token).
overlay: OverlayCommitsIntoOnePullRequestCombine multiple issue groups into one PR.
When this flag is active, git-disjoint will create only one PR.
This can be useful when you have multiple commits with no trailer that would be better reviewed or merged together.
ready: boolCreate pull requests as ready for review.
By default, git-disjoint creates draft pull requests. Use this flag to mark pull requests as ready for review immediately.
separate: CommitGroupingDo not group commits by issue.
Treat each commit independently, regardless of issue trailer. Each PR created will have one and only one commit associated with it.
This is the same behavior as when no commit has an issue trailer and the –all flag is active.
This can be useful when you have numerous changes that belong under one issue, but would be better reviewed independently.